##  Overview
The Tech Category is used to group IT Components into different categories of technology. This could be a Database, an Operating System, or a Server Software. The Tech Category model is relatively stable over time and independent of specific industries.
